==> zio-aws-sagemaker_3-5.20.22.2-sources.jar: zio/aws/sagemaker/model/AutoMLChannel.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{ContentType, TargetAttributeName}
import scala.jdk.CollectionConverters.*
final case class AutoMLChannel(
    dataSource: zio.aws.sagemaker.model.AutoMLDataSource,
    compressionType: Optional[zio.aws.sagemaker.model.CompressionType] =
      Optional.Absent,
    targetAttributeName: TargetAttributeName,
    contentType: Optional[ContentType] = Optional.Absent,
    channelType: Optional[zio.aws.sagemaker.model.AutoMLChannelType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AutoMLChannel = {
    import AutoMLChannel.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
      .builder()
      .dataSource(dataSource.buildAwsValue())
      .optionallyWith(compressionType.map(value => value.unwrap))(
        _.compressionType
      )
      .targetAttributeName(
        TargetAttributeName.unwrap(targetAttributeName): java.lang.String
      )
      .optionallyWith(
        contentType.map(value => ContentType.unwrap(value): java.lang.String)
      )(_.contentType)
      .optionallyWith(channelType.map(value => value.unwrap))(_.channelType)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AutoMLChannel.ReadOnly =
    zio.aws.sagemaker.model.AutoMLChannel.wrap(buildAwsValue())
}
object AutoMLChannel {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AutoMLChannel =
      zio.aws.sagemaker.model.AutoMLChannel(
        dataSource.asEditable,
        compressionType.map(value => value),
        targetAttributeName,
        contentType.map(value => value),
        channelType.map(value => value)
      )
    def dataSource: zio.aws.sagemaker.model.AutoMLDataSource.ReadOnly
    def compressionType: Optional[zio.aws.sagemaker.model.CompressionType]
    def targetAttributeName: TargetAttributeName
    def contentType: Optional[ContentType]
    def channelType: Optional[zio.aws.sagemaker.model.AutoMLChannelType]
    def getDataSource
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.AutoMLDataSource.ReadOnly] =
      ZIO.succeed(dataSource)
    def getCompressionType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.CompressionType] =
      AwsError.unwrapOptionField("compressionType", compressionType)
    def getTargetAttributeName: ZIO[Any, Nothing, TargetAttributeName] =
      ZIO.succeed(targetAttributeName)
    def getContentType: ZIO[Any, AwsError, ContentType] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getChannelType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.AutoMLChannelType] =
      AwsError.unwrapOptionField("channelType", channelType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
  ) extends zio.aws.sagemaker.model.AutoMLChannel.ReadOnly {
    override val dataSource: zio.aws.sagemaker.model.AutoMLDataSource.ReadOnly =
      zio.aws.sagemaker.model.AutoMLDataSource.wrap(impl.dataSource())
    override val compressionType
        : Optional[zio.aws.sagemaker.model.CompressionType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.compressionType())
        .map(value => zio.aws.sagemaker.model.CompressionType.wrap(value))
    override val targetAttributeName: TargetAttributeName =
      zio.aws.sagemaker.model.primitives
        .TargetAttributeName(impl.targetAttributeName())
    override val contentType: Optional[ContentType] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => zio.aws.sagemaker.model.primitives.ContentType(value))
    override val channelType
        : Optional[zio.aws.sagemaker.model.AutoMLChannelType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.channelType())
        .map(value => zio.aws.sagemaker.model.AutoMLChannelType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
  ): zio.aws.sagemaker.model.AutoMLChannel.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-7.21.15.7-sources.jar: zio/aws/sagemaker/model/AutoMLChannel.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{
  SampleWeightAttributeName,
  ContentType,
  TargetAttributeName
}
import scala.jdk.CollectionConverters.*
final case class AutoMLChannel(
    dataSource: zio.aws.sagemaker.model.AutoMLDataSource,
    compressionType: Optional[zio.aws.sagemaker.model.CompressionType] =
      Optional.Absent,
    targetAttributeName: TargetAttributeName,
    contentType: Optional[ContentType] = Optional.Absent,
    channelType: Optional[zio.aws.sagemaker.model.AutoMLChannelType] =
      Optional.Absent,
    sampleWeightAttributeName: Optional[SampleWeightAttributeName] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AutoMLChannel = {
    import AutoMLChannel.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
      .builder()
      .dataSource(dataSource.buildAwsValue())
      .optionallyWith(compressionType.map(value => value.unwrap))(
        _.compressionType
      )
      .targetAttributeName(
        TargetAttributeName.unwrap(targetAttributeName): java.lang.String
      )
      .optionallyWith(
        contentType.map(value => ContentType.unwrap(value): java.lang.String)
      )(_.contentType)
      .optionallyWith(channelType.map(value => value.unwrap))(_.channelType)
      .optionallyWith(
        sampleWeightAttributeName.map(value =>
          SampleWeightAttributeName.unwrap(value): java.lang.String
        )
      )(_.sampleWeightAttributeName)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AutoMLChannel.ReadOnly =
    zio.aws.sagemaker.model.AutoMLChannel.wrap(buildAwsValue())
}
object AutoMLChannel {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AutoMLChannel =
      zio.aws.sagemaker.model.AutoMLChannel(
        dataSource.asEditable,
        compressionType.map(value => value),
        targetAttributeName,
        contentType.map(value => value),
        channelType.map(value => value),
        sampleWeightAttributeName.map(value => value)
      )
    def dataSource: zio.aws.sagemaker.model.AutoMLDataSource.ReadOnly
    def compressionType: Optional[zio.aws.sagemaker.model.CompressionType]
    def targetAttributeName: TargetAttributeName
    def contentType: Optional[ContentType]
    def channelType: Optional[zio.aws.sagemaker.model.AutoMLChannelType]
    def sampleWeightAttributeName: Optional[SampleWeightAttributeName]
    def getDataSource
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.AutoMLDataSource.ReadOnly] =
      ZIO.succeed(dataSource)
    def getCompressionType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.CompressionType] =
      AwsError.unwrapOptionField("compressionType", compressionType)
    def getTargetAttributeName: ZIO[Any, Nothing, TargetAttributeName] =
      ZIO.succeed(targetAttributeName)
    def getContentType: ZIO[Any, AwsError, ContentType] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getChannelType
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.AutoMLChannelType] =
      AwsError.unwrapOptionField("channelType", channelType)
    def getSampleWeightAttributeName
        : ZIO[Any, AwsError, SampleWeightAttributeName] = AwsError
      .unwrapOptionField("sampleWeightAttributeName", sampleWeightAttributeName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
  ) extends zio.aws.sagemaker.model.AutoMLChannel.ReadOnly {
    override val dataSource: zio.aws.sagemaker.model.AutoMLDataSource.ReadOnly =
      zio.aws.sagemaker.model.AutoMLDataSource.wrap(impl.dataSource())
    override val compressionType
        : Optional[zio.aws.sagemaker.model.CompressionType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.compressionType())
        .map(value => zio.aws.sagemaker.model.CompressionType.wrap(value))
    override val targetAttributeName: TargetAttributeName =
      zio.aws.sagemaker.model.primitives
        .TargetAttributeName(impl.targetAttributeName())
    override val contentType: Optional[ContentType] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => zio.aws.sagemaker.model.primitives.ContentType(value))
    override val channelType
        : Optional[zio.aws.sagemaker.model.AutoMLChannelType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.channelType())
        .map(value => zio.aws.sagemaker.model.AutoMLChannelType.wrap(value))
    override val sampleWeightAttributeName
        : Optional[SampleWeightAttributeName] = zio.aws.core.internal
      .optionalFromNullable(impl.sampleWeightAttributeName())
      .map(value =>
        zio.aws.sagemaker.model.primitives.SampleWeightAttributeName(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLChannel
  ): zio.aws.sagemaker.model.AutoMLChannel.ReadOnly = new Wrapper(impl)
}
